==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/WebClipboardOptionsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebClipboardOptionsDescription } from "./WebClipboardOptionsDescription";
/**
 * @hidden
 */
export let WebClipboardOptionsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebClipboardOptionsDescriptionMetadata extends Base {
        static b(a) {
            if (WebClipboardOptionsDescriptionMetadata.a == null) {
                WebClipboardOptionsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebClipboardOptionsDescriptionMetadata.c(WebClipboardOptionsDescriptionMetadata.a);
            }
            if (a.k(WebClipboardOptionsDescriptionMetadata.a)) {
                return;
            }
            a.ab(WebClipboardOptionsDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:ClipboardOptions");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__isPlainObject", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("Enabled", "Boolean");
            a.item("CopyHeaders", "Boolean");
            a.item("CopyFormatters", "Boolean");
            a.item("Separator", "String");
        }
        static d(a) {
            WebClipboardOptionsDescriptionMetadata.b(a);
            a.ad("WebClipboardOptions", () => new WebClipboardOptionsDescription());
            a.ac("WebClipboardOptions", WebClipboardOptionsDescriptionMetadata.a);
        }
    }
    WebClipboardOptionsDescriptionMetadata.$t = markType(WebClipboardOptionsDescriptionMetadata, 'WebClipboardOptionsDescriptionMetadata');
    WebClipboardOptionsDescriptionMetadata.a = null;
    return WebClipboardOptionsDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/WebClipboardOptionsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebClipboardOptionsDescription } from "./WebClipboardOptionsDescription";
/**
 * @hidden
 */
export let WebClipboardOptionsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebClipboardOptionsDescriptionMetadata extends Base {
        static b(a) {
            if (WebClipboardOptionsDescriptionMetadata.a == null) {
                WebClipboardOptionsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebClipboardOptionsDescriptionMetadata.c(WebClipboardOptionsDescriptionMetadata.a);
            }
            if (a.k(WebClipboardOptionsDescriptionMetadata.a)) {
                return;
            }
            a.ac(WebClipboardOptionsDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:ClipboardOptions");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__isPlainObject", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("Enabled", "Boolean");
            a.item("CopyHeaders", "Boolean");
            a.item("CopyFormatters", "Boolean");
            a.item("Separator", "String");
        }
        static d(a) {
            WebClipboardOptionsDescriptionMetadata.b(a);
            a.ae("WebClipboardOptions", () => new WebClipboardOptionsDescription());
            a.ad("WebClipboardOptions", WebClipboardOptionsDescriptionMetadata.a);
        }
    }
    WebClipboardOptionsDescriptionMetadata.$t = markType(WebClipboardOptionsDescriptionMetadata, 'WebClipboardOptionsDescriptionMetadata');
    WebClipboardOptionsDescriptionMetadata.a = null;
    return WebClipboardOptionsDescriptionMetadata;
})();
